@@ -252,6 +252,29 @@ void KMKernel::migrateFromKMail1()
     const int currentVersion = migrationCfg.readEntry( "Version", 0 );
     const int targetVersion = migrationCfg.readEntry( "TargetVersion", 1 );
     if ( enabled && currentVersion < targetVersion ) {
+      const int choice = KMessageBox::questionYesNoCancel( 0, i18n(
+          "<b>Thanks for using KMail2!</b>"
+          "<p>KMail2 uses a new storage technology that requires migration of your current KMail data and configuration.</p>\n"
+          "<p>The conversion process can take a lot of time (depending on the amount of email you have) and it <em>must not be interrupted</em>.</p>\n"
+          "<p>You can:</p><ul>"
+          "<li>Migrate now (be prepared to wait)</li>"
+          "<li>Skip the migration and start with fresh data and configuration</li>"
+          "<li>Cancel and exit KMail2.</li>"
+          "</ul>"
+          "<p><a href=\"http://userbase.kde.org/Akonadi\">More Information...</a></p>"
+        ), i18n( "KMail Migration" ), KGuiItem(i18n( "Migrate Now" )), KGuiItem(i18n( "Skip Migration" )), KStandardGuiItem::cancel(),
+        QString(), KMessageBox::Notify | KMessageBox::Dangerous | KMessageBox::AllowLink );
+      if ( choice == KMessageBox::Cancel )
+        exit( 1 );
+
+      // we only will make one attempt at this
+      migrationCfg.writeEntry( "Version", targetVersion );
+      migrationCfg.sync();
+
+      if ( choice != KMessageBox::Yes ) {
+        return;
+      }
+
       kDebug() << "Performing Akonadi migration. Good luck!";
       KProcess proc;
       QStringList args = QStringList() << "--interactive-on-change";
@@ -264,8 +287,6 @@ void KMKernel::migrateFromKMail1()
       }
       if ( result && proc.exitCode() == 0 ) {
         kDebug() << "Akonadi migration has been successful";
-        migrationCfg.writeEntry( "Version", targetVersion );
-        migrationCfg.sync();
       } else {
         // exit code 1 means it is already running, so we are probably called by a migrator instance
         kError() << "Akonadi migration failed!";
@@ -273,7 +294,10 @@ void KMKernel::migrateFromKMail1()
         kError() << "exit code: " << proc.exitCode();
         kError() << "stdout: " << proc.readAllStandardOutput();
         kError() << "stderr: " << proc.readAllStandardError();
-        exit( 42 );
+
+        KMessageBox::error( 0, i18n("Migration to KMail 2 failed. In case you want to try again, run 'kmail-migrator --interactive' manually."),
+          i18n( "Migration Failed" ) );
+        return;
       }
     }
   } else {
@@ -1402,8 +1426,6 @@ KSharedConfig::Ptr KMKernel::config()
     KMail::checkConfigUpdates();
     MessageList::Core::Settings::self()->setSharedConfig( mySelf->mConfig );
     MessageList::Core::Settings::self()->readConfig();
-    MessageViewer::GlobalSettings::self()->setSharedConfig( mySelf->mConfig );
-    MessageViewer::GlobalSettings::self()->readConfig();
     TemplateParser::GlobalSettings::self()->setSharedConfig( mySelf->mConfig );
     TemplateParser::GlobalSettings::self()->readConfig();
     MessageComposer::MessageComposerSettings::self()->setSharedConfig( mySelf->mConfig );
