@@ -25,15 +25,15 @@
 #include <QtGui/QWidget>
 
 #include <korganizer/baseview.h>
-#include <akonadi/kcal/incidencechanger.h>
+#include <calendarsupport/incidencechanger.h>
+
+namespace CalendarSupport {
+  class Calendar;
+  class IncidenceChanger;
+}
 
 namespace Akonadi {
   class Item;
-  class Calendar;
-}
-
-namespace IncidenceEditors {
-  class IncidenceEditor;
 }
 
 namespace KOrg {
@@ -48,8 +48,8 @@ class CalendarViewBase : public QWidget
     explicit CalendarViewBase( QWidget *parent ) : QWidget( parent ) {}
     virtual ~CalendarViewBase() {}
 
-    virtual Akonadi::Calendar *calendar() = 0;
-    virtual Akonadi::IncidenceChanger *incidenceChanger() const = 0;
+    virtual CalendarSupport::Calendar *calendar() const = 0;
+    virtual CalendarSupport::IncidenceChanger *incidenceChanger() const = 0;
 
     virtual QDate startDate() = 0;
     virtual QDate endDate() = 0;
@@ -63,14 +63,15 @@ class CalendarViewBase : public QWidget
 
     virtual bool editIncidence( const Akonadi::Item &item, bool isCounter = false ) = 0;
 
-    virtual IncidenceEditors::IncidenceEditor *editorDialog( const Akonadi::Item &item ) const = 0;
+    // TODO_NG: remove me
+    // virtual IncidenceEditors::IncidenceEditor *editorDialog( const Akonadi::Item &item ) const = 0;
 
   public Q_SLOTS:
     virtual void updateView() = 0;
     virtual void updateCategories() = 0;
 
   signals:
-    virtual void newIncidenceChanger( Akonadi::IncidenceChanger * ) = 0;
+    virtual void newIncidenceChanger( CalendarSupport::IncidenceChanger * ) = 0;
 
 };
 
