@@ -56,7 +56,7 @@ using namespace KOrg;
 
 namespace KCalCore {
   class CalFilter;
-};
+}
 
 /**
   This class manages the views of the calendar. It owns the objects and handles
@@ -96,7 +96,7 @@ class KOViewManager : public QObject
     void setDocumentId( const QString & );
 
     void updateView();
-    void updateView( const QDate &start, const QDate &end );
+    void updateView( const QDate &start, const QDate &end, const QDate &preferredMonth );
 
     void goMenu( bool enable );
     void raiseCurrentView();
