@@ -54,17 +54,17 @@ class HebrewDate
     static HebrewDate fromSecular( int year, int month, int day );
     static HebrewDate fromHebrew( int year, int month, int day );
 
-    int year();
-    int month();
-    int day();
-    int dayOfWeek();
+    int year() const;
+    int month() const;
+    int day() const;
+    int dayOfWeek() const;
 
-    int hebrewMonthLength();
-    int secularMonthLength();
-    bool isOnHebrewLeapYear();
-    bool isOnSecularLeapYear();
-    int kvia();
-    int hebrewDayNumber();
+    int hebrewMonthLength() const;
+    int secularMonthLength() const;
+    bool isOnHebrewLeapYear() const;
+    bool isOnSecularLeapYear() const;
+    int kvia() const;
+    int hebrewDayNumber() const;
 
   private:
     int mYear, mMonth, mDay, mDayOfWeek;
@@ -132,7 +132,7 @@ class Converter
     static void gregorian_from_absolute( long date, int *yearp,
                                          int *monthp, int *dayp );
     static void hebrew_from_absolute( long date, int *yearp, int *monthp,
-                                      int *dayp);
+                                      int *dayp );
 
     static int hebrew_months_in_year( int year );
     static int hebrew_month_length( int year, int month );
