@@ -115,7 +115,6 @@ void KDescendantsProxyModelPrivate::synchronousMappingRefresh()
 
 void KDescendantsProxyModelPrivate::scheduleProcessPendingParents() const
 {
-  Q_Q(const KDescendantsProxyModel);
   const_cast<KDescendantsProxyModelPrivate*>(this)->processPendingParents();
 }
 
@@ -171,7 +170,10 @@ void KDescendantsProxyModelPrivate::processPendingParents()
       Q_ASSERT(child.isValid());
 
       if (q->sourceModel()->hasChildren(child))
+      {
+        Q_ASSERT(q->sourceModel()->rowCount(child) > 0);
         newPendingParents.append(child);
+      }
     }
   }
   m_pendingParents += newPendingParents;
@@ -185,8 +187,8 @@ void KDescendantsProxyModelPrivate::updateInternalIndexes(int start, int offset)
   // TODO: Make KHash2Map support key updates and do this backwards.
   QHash<int, QPersistentModelIndex> updates;
   {
-    Mapping::right_const_iterator it = const_cast<const Mapping&>(m_mapping).rightLowerBound(start);
-    const Mapping::right_const_iterator end = m_mapping.rightConstEnd();
+    Mapping::right_iterator it = m_mapping.rightLowerBound(start);
+    const Mapping::right_iterator end = m_mapping.rightEnd();
 
     while (it != end)
     {
@@ -335,6 +337,7 @@ int KDescendantsProxyModel::rowCount(const QModelIndex &parent) const
 
   if (d->m_mapping.isEmpty() && sourceModel()->hasChildren())
   {
+    Q_ASSERT(sourceModel()->rowCount() > 0);
     const_cast<KDescendantsProxyModelPrivate*>(d)->synchronousMappingRefresh();
   }
   return d->m_rowCount;
@@ -538,6 +541,7 @@ void KDescendantsProxyModelPrivate::sourceRowsAboutToBeInserted(const QModelInde
 
   if (!q->sourceModel()->hasChildren(parent))
   {
+    Q_ASSERT(q->sourceModel()->rowCount(parent) == 0);
     // parent was not a parent before.
     return;
   }
@@ -559,6 +563,7 @@ void KDescendantsProxyModelPrivate::sourceRowsAboutToBeInserted(const QModelInde
     QModelIndex idx = q->sourceModel()->index(rowCount - 1, column, parent);
     while (q->sourceModel()->hasChildren(idx))
     {
+      Q_ASSERT(q->sourceModel()->rowCount(idx) > 0);
       idx = q->sourceModel()->index(q->sourceModel()->rowCount(idx) - 1, column, idx);
     }
     // The last item in the list is getting a sibling below it.
@@ -634,12 +639,36 @@ void KDescendantsProxyModelPrivate::sourceRowsInserted(const QModelIndex &parent
     const QModelIndex oldIndex = q->sourceModel()->index(rowCount - 1 - difference, column, parent);
     Q_ASSERT(m_mapping.leftContains(oldIndex));
 
-    // oldIndex is E in the source. proxyRow is 4.
-    const int proxyRow = m_mapping.takeLeft(oldIndex);
     const QModelIndex newIndex = q->sourceModel()->index(rowCount - 1, column, parent);
 
+    QModelIndex indexAbove = oldIndex;
+
+    if (start > 0) {
+      // If we have something like this:
+      //
+      // - A
+      // - - B
+      // - - C
+      //
+      // and we then insert D as a sibling of A below it, we need to remove the mapping for A,
+      // and the row number used for D must take into account the descendants of A.
+
+      while (q->sourceModel()->hasChildren(indexAbove)) {
+      Q_ASSERT(q->sourceModel()->rowCount(indexAbove) > 0);
+        indexAbove = q->sourceModel()->index(q->sourceModel()->rowCount(indexAbove) - 1,  column, indexAbove);
+      }
+      Q_ASSERT(q->sourceModel()->rowCount(indexAbove) == 0);
+    }
+
+    Q_ASSERT(m_mapping.leftContains(indexAbove));
+
+    const int newProxyRow = m_mapping.leftToRight(indexAbove) + difference;
+
+    // oldIndex is E in the source. proxyRow is 4.
+    m_mapping.removeLeft(oldIndex);
+
     // newIndex is J. (proxyRow + difference) is 5.
-    m_mapping.insert(newIndex, proxyRow + difference);
+    m_mapping.insert(newIndex, newProxyRow);
   }
 
   for (int row = start; row <= end; ++row)
@@ -648,13 +677,16 @@ void KDescendantsProxyModelPrivate::sourceRowsInserted(const QModelIndex &parent
     const QModelIndex idx = q->sourceModel()->index(row, column, parent);
     Q_ASSERT(idx.isValid());
     if (q->sourceModel()->hasChildren(idx))
+    {
+      Q_ASSERT(q->sourceModel()->rowCount(idx) > 0);
       m_pendingParents.append(idx);
+    }
   }
 
   m_rowCount += difference;
 
-  scheduleProcessPendingParents();
   q->endInsertRows();
+  scheduleProcessPendingParents();
 }
 
 void KDescendantsProxyModelPrivate::sourceRowsAboutToBeRemoved(const QModelIndex &parent, int start, int end)
@@ -667,6 +699,7 @@ void KDescendantsProxyModelPrivate::sourceRowsAboutToBeRemoved(const QModelIndex
   QModelIndex idx = q->sourceModel()->index(end, column, parent);
   while (q->sourceModel()->hasChildren(idx))
   {
+    Q_ASSERT(q->sourceModel()->rowCount(idx) > 0);
     idx = q->sourceModel()->index(q->sourceModel()->rowCount(idx) - 1, column, idx);
   }
   const int proxyEnd = q->mapFromSource(idx).row();
@@ -676,6 +709,20 @@ void KDescendantsProxyModelPrivate::sourceRowsAboutToBeRemoved(const QModelIndex
   q->beginRemoveRows(QModelIndex(), proxyStart, proxyEnd);
 }
 
+static QModelIndex getFirstDeepest(QAbstractItemModel *model, const QModelIndex &parent, int *count) {
+  static const int column = 0;
+  Q_ASSERT(model->hasChildren(parent));
+  Q_ASSERT(model->rowCount(parent) > 0);
+  for (int row = 0; row < model->rowCount(parent); ++row) {
+    (*count)++;
+    const QModelIndex child = model->index(row, column, parent);
+    Q_ASSERT(child.isValid());
+    if (model->hasChildren(child))
+      return getFirstDeepest(model, child, count);
+  }
+  return model->index(model->rowCount(parent) - 1, column, parent);
+}
+
 void KDescendantsProxyModelPrivate::sourceRowsRemoved(const QModelIndex &parent, int start, int end)
 {
   Q_Q(KDescendantsProxyModel);
@@ -706,13 +753,104 @@ void KDescendantsProxyModelPrivate::sourceRowsRemoved(const QModelIndex &parent,
 
   updateInternalIndexes(proxyStart, -1 * difference);
 
-  if (rowCount == start && rowCount != 0)
-  {
-    static const int column = 0;
-    const QModelIndex newIndex = q->sourceModel()->index(rowCount - 1, column, parent);
-    m_mapping.insert(newIndex, proxyStart - 1);
+  if (rowCount != start || rowCount == 0) {
+    q->endRemoveRows();
+    return;
   }
 
+  static const int column = 0;
+  const QModelIndex newEnd = q->sourceModel()->index(rowCount - 1, column, parent);
+  Q_ASSERT(newEnd.isValid());
+
+  if (m_mapping.isEmpty()) {
+    m_mapping.insert(newEnd, newEnd.row());
+    q->endRemoveRows();
+    return;
+  }
+  if (q->sourceModel()->hasChildren(newEnd)) {
+    int count = 0;
+    const QModelIndex firstDeepest = getFirstDeepest(q->sourceModel(), newEnd, &count);
+    Q_ASSERT(firstDeepest.isValid());
+    const int firstDeepestProxy = m_mapping.leftToRight(firstDeepest);
+
+    m_mapping.insert(newEnd, firstDeepestProxy - count);
+    q->endRemoveRows();
+    return;
+  }
+  Mapping::right_iterator lowerBound = m_mapping.rightLowerBound(proxyStart);
+  if (lowerBound == m_mapping.rightEnd()) {
+    int proxyRow = (lowerBound - 1).key();
+
+    for (int row = newEnd.row(); row >= 0; --row ) {
+      const QModelIndex newEndSibling = q->sourceModel()->index(row, column, parent);
+      if (!q->sourceModel()->hasChildren(newEndSibling)) {
+        ++proxyRow;
+      } else {
+        break;
+      }
+    }
+    m_mapping.insert(newEnd, proxyRow);
+    q->endRemoveRows();
+    return;
+  } else if (lowerBound == m_mapping.rightBegin()) {
+    int proxyRow = rowCount - 1;
+    QModelIndex trackedParent = parent;
+    while (trackedParent.isValid()) {
+      proxyRow += (trackedParent.row() + 1);
+      trackedParent = trackedParent.parent();
+    }
+    m_mapping.insert(newEnd, proxyRow);
+    q->endRemoveRows();
+    return;
+  }
+  const Mapping::right_iterator boundAbove = lowerBound - 1;
+
+  QVector<QModelIndex> targetParents;
+  targetParents.push_back(parent);
+  {
+    QModelIndex target = parent;
+    int count = 0;
+    while (target.isValid()) {
+      if (target == boundAbove.value()) {
+        m_mapping.insert(newEnd, count + boundAbove.key() + newEnd.row() + 1);
+        q->endRemoveRows();
+        return;
+      }
+      count += (target.row() + 1);
+      target = target.parent();
+      if (target.isValid())
+        targetParents.push_back(target);
+    }
+  }
+
+  QModelIndex boundParent = boundAbove.value().parent();
+  QModelIndex prevParent = boundParent;
+  Q_ASSERT(boundParent.isValid());
+  while (boundParent.isValid()) {
+    prevParent = boundParent;
+    boundParent = boundParent.parent();
+
+    if (targetParents.contains(prevParent))
+      break;
+
+    if (!m_mapping.leftContains(prevParent))
+      break;
+
+    if (m_mapping.leftToRight(prevParent) > boundAbove.key())
+      break;
+  }
+
+  QModelIndex trackedParent = parent;
+
+  int proxyRow = boundAbove.key();
+
+  Q_ASSERT(prevParent.isValid());
+  proxyRow -= prevParent.row();
+  while (trackedParent != boundParent) {
+    proxyRow += (trackedParent.row() + 1);
+    trackedParent = trackedParent.parent();
+  }
+  m_mapping.insert(newEnd, proxyRow + newEnd.row());
   q->endRemoveRows();
 }
 
@@ -751,6 +889,7 @@ void KDescendantsProxyModelPrivate::sourceModelReset()
   resetInternalData();
   if (q->sourceModel()->hasChildren())
   {
+    Q_ASSERT(q->sourceModel()->rowCount() > 0);
     m_pendingParents.append(QModelIndex());
     scheduleProcessPendingParents();
   }
