@@ -1198,3 +1198,12 @@ QDataStream & SearchPattern::operator <<( QDataStream &s )
   return s;
 }
 
+// Needed for MSVC 2010, as it seems to not implicit cast for a pointer anymore
+#ifdef _MSC_VER
+namespace MailCommon {
+uint qHash(SearchRule::Ptr sr)
+{
+  return ::qHash(sr.get());
+}
+}
+#endif
