@@ -911,16 +911,13 @@ void Message::ComposerViewBase::writeAutoSaveToDisk( KMime::Message::Ptr message
 void Message::ComposerViewBase::saveMessage( KMime::Message::Ptr message, MessageSender::SaveIn saveIn )
 {
   Akonadi::Collection target;
-
-  // preinitialize with the default collections
-  if ( saveIn == MessageSender::SaveInTemplates ) {
-    target = Akonadi::SpecialMailCollections::self()->defaultCollection( Akonadi::SpecialMailCollections::Templates );
-  } else {
-    target = Akonadi::SpecialMailCollections::self()->defaultCollection( Akonadi::SpecialMailCollections::Drafts );
-  }
-
-  // overwrite with identity specific collections if available
   const KPIMIdentities::Identity identity = identityManager()->identityForUoid( m_identityCombo->currentIdentity() );
+  message->date()->setDateTime( KDateTime::currentLocalDateTime() );
+  message->assemble();
+
+  Akonadi::Item item;
+  item.setMimeType( QLatin1String( "message/rfc822" ) );
+  item.setPayload( message );
   if ( !identity.isNull() ) { // we have a valid identity
     if ( saveIn == MessageSender::SaveInTemplates ) {
       if ( !identity.templates().isEmpty() ) { // the user has specified a custom templates collection
@@ -931,24 +928,38 @@ void Message::ComposerViewBase::saveMessage( KMime::Message::Ptr message, Messag
         target = Akonadi::Collection( identity.drafts().toLongLong() );
       }
     }
+    Akonadi::CollectionFetchJob *saveMessageJob = new Akonadi::CollectionFetchJob( target, Akonadi::CollectionFetchJob::Base );
+    saveMessageJob->setProperty( "Akonadi::Item" , QVariant::fromValue( item )  );
+    QObject::connect( saveMessageJob, SIGNAL( result( KJob * ) ), this, SLOT( slotSaveMessage( KJob* ) ) );
+  } else {
+    // preinitialize with the default collections
+    if ( saveIn == MessageSender::SaveInTemplates ) {
+      target = Akonadi::SpecialMailCollections::self()->defaultCollection( Akonadi::SpecialMailCollections::Templates );
+    } else {
+      target = Akonadi::SpecialMailCollections::self()->defaultCollection( Akonadi::SpecialMailCollections::Drafts );
+    }
+    Akonadi::ItemCreateJob *create = new Akonadi::ItemCreateJob( item, target, this );
+    connect( create, SIGNAL( result( KJob* ) ), this, SLOT( slotCreateItemResult( KJob* ) ) );
+    m_pendingQueueJobs++;
   }
+}
 
-  if ( !target.isValid() ) {
-    kWarning() << "No default collection for" << saveIn;
-    emit failed( i18n( "No default collection for %1", saveIn ) );
-//     setEnabled( true );
-    return;
+void Message::ComposerViewBase::slotSaveMessage( KJob* job )
+{
+  Akonadi::Collection target;
+  Akonadi::Item item = job->property( "Akonadi::Item" ).value<Akonadi::Item>();
+  if( job->error() ) {
+    if ( mSaveIn == MessageSender::SaveInTemplates ) {
+      target = Akonadi::SpecialMailCollections::self()->defaultCollection( Akonadi::SpecialMailCollections::Templates );
+    } else {
+      target = Akonadi::SpecialMailCollections::self()->defaultCollection( Akonadi::SpecialMailCollections::Drafts );
+    }
+  } else {
+    const Akonadi::CollectionFetchJob *fetchJob = qobject_cast<Akonadi::CollectionFetchJob*>( job );
+    target = fetchJob->collections().first();
   }
-
-  // Store when the draft or template got saved.
-  message->date()->setDateTime( KDateTime::currentLocalDateTime() );
-  message->assemble();
-
-  Akonadi::Item item;
-  item.setMimeType( QLatin1String( "message/rfc822" ) );
-  item.setPayload( message );
   Akonadi::ItemCreateJob *create = new Akonadi::ItemCreateJob( item, target, this );
-  connect( create, SIGNAL( result( KJob* ) ), this, SLOT( slotCreateItemResult(KJob*) ) );
+  connect( create, SIGNAL( result( KJob* ) ), this, SLOT( slotCreateItemResult( KJob* ) ) );
   m_pendingQueueJobs++;
 }
 
