@@ -17,6 +17,8 @@
     02110-1301, USA.
 */
 
+#include <config-messageviewer.h>
+
 #include "mimetreemodel.h"
 
 #include "nodehelper.h"
@@ -53,8 +55,9 @@ class MimeTreeModel::Private
 
     QString descriptionForContent( KMime::Content *content )
     {
-      if ( content->hasHeader( "Subject" ) )
-        return content->getHeaderByType( "Subject" )->asUnicodeString();
+      KMime::Message * const message = dynamic_cast<KMime::Message*>( content );
+      if ( message && message->subject( false ) )
+        return message->subject()->asUnicodeString();
       const QString name = NodeHelper::fileName( content );
       if ( !name.isEmpty() )
         return name;
@@ -215,6 +218,12 @@ QVariant MimeTreeModel::data(const QModelIndex & index, int role) const
       return false;
     return topLevelMsg->mainBodyPart() == content;
   }
+  if ( role == AlternativeBodyPartRole ) {
+    KMime::Message* topLevelMsg = dynamic_cast<KMime::Message*>( d->root );
+    if ( !topLevelMsg )
+      return false;
+    return topLevelMsg->mainBodyPart( content->contentType()->mimeType() ) == content;
+  }
   return QVariant();
 }
 
