@@ -19,9 +19,11 @@
  */
 
 #include "templateparser.h"
-#include "templatesconfiguration.h"
-#include "templatesconfiguration_kfg.h"
+#ifndef Q_OS_WINCE
 #include "customtemplates_kfg.h"
+#include "templatesconfiguration_kfg.h"
+#include "templatesconfiguration.h"
+#endif
 #include "globalsettings_base.h"
 
 
@@ -58,7 +60,11 @@
 #include <QWebElement>
 #include <QTextCodec>
 #include <QWebFrame>
-#include <QtWebKit/QWebPage>
+#ifdef KDEPIM_NO_WEBKIT
+# include <QTextBrowser>
+#else
+# include <QtWebKit/QWebPage>
+#endif
 
 namespace TemplateParser {
 
@@ -88,7 +94,7 @@ QByteArray selectCharset( const QStringList &charsets, const QString &text )
 }
 
 TemplateParser::TemplateParser( const KMime::Message::Ptr &amsg, const Mode amode ) :
-  mMode( amode ), mFolder( 0 ), mIdentity( 0 ),
+  mMode( amode ), mIdentity( 0 ),
   mAllowDecryption( false ),
   mDebug( false ), mQuoteString( "> " ), mOrigRoot( 0 ), m_identityManager( 0 ), mWrap( true ), mColWrap( 80 )
 {
@@ -108,7 +114,11 @@ void TemplateParser::setAllowDecryption( const bool allowDecryption )
 bool TemplateParser::shouldStripSignature() const
 {
   // Only strip the signature when replying, it should be preserved when forwarding
-  return ( mMode == Reply || mMode == ReplyAll ) && GlobalSettings::self()->stripSignature();
+  return ( mMode == Reply || mMode == ReplyAll )
+#ifndef Q_OS_WINCE
+  && GlobalSettings::self()->stripSignature()
+#endif
+  ;
 }
 
 void TemplateParser::setIdentityManager( KPIMIdentities::IdentityManager* ident)
@@ -1068,6 +1078,7 @@ void TemplateParser::addProcessedBodyToMessage( const QString &body )
 
 QString TemplateParser::findCustomTemplate( const QString &tmplName )
 {
+#ifndef Q_OS_WINCE
   CTemplates t( tmplName );
   mTo = t.to();
   mCC = t.cC();
@@ -1077,6 +1088,9 @@ QString TemplateParser::findCustomTemplate( const QString &tmplName )
   } else {
     return findTemplate();
   }
+#else
+    return findTemplate();
+#endif
 }
 
 QString TemplateParser::findTemplate()
@@ -1084,6 +1098,8 @@ QString TemplateParser::findTemplate()
   // kDebug() << "Trying to find template for mode" << mode;
 
   QString tmpl;
+#ifndef Q_OS_WINCE
+
 #if 0
   if ( !mFolder.isValid() ) { // find folder message belongs to
     mFolder = mMsg->parentCollection();
@@ -1176,6 +1192,7 @@ QString TemplateParser::findTemplate()
       return tmpl;  // use identity-specific template
     }
   }
+#endif
 
   switch( mMode ) { // use the global template
   case NewMessage:
@@ -1195,7 +1212,7 @@ QString TemplateParser::findTemplate()
     return "";
   }
 
-  mQuoteString = TemplatesConfiguration::defaultQuoteString();
+  mQuoteString = DefaultTemplates::defaultQuoteString();
   return tmpl;
 }
 
@@ -1279,20 +1296,44 @@ QString TemplateParser::asPlainTextFromObjectTree( const KMime::Message::Ptr &ms
   bool isHTML = false;
   const QTextCodec * codec = 0;
 
-  if ( !root ) return QString();
+  if ( !root )
+    return QString();
+
+  /*
+   * FIXME
+   * The below is weird. It tries to find a text node, then uses
+   * that for the reply string, instead of relying on the OTP to
+   * provide one. In order to make replies to encrypted mails work,
+   * I added a fall back to the rawReplyString from the OTP, but
+   * it seems to me like that one should always be used? Also, why
+   * is the legacy pgp handling in here and not handled by the OTP?
+   * Wonderous and wonderouser. I'm also not sure, but it's pretty
+   * likely that the OTP also handles the whole codec mess already.
+   * Needs to be verified.
+   */
+
+  // first try if we have a text node
   parseTextStringFromContent( root, parsedString, codec, isHTML );
 
-#if 0 //TODO port to akonadi
-  if ( mOverrideCodec || !codec )
-    codec = otp->nodeHelper()->codec( msg );
-#else
-  kDebug() << "AKONADI PORT: Disabled code in  " << Q_FUNC_INFO;
-#endif
+  // otherwise check what the OTP thinks we should use
+  if ( parsedString.isEmpty() ) {
+    // extract the already parsed reply string from the OTP
+    parsedString = otp->rawReplyString();
+  }
+
   if ( parsedString.isEmpty() )
     return QString();
 
   bool clearSigned = false;
   QString result;
+#if 0 //TODO port to akonadi
+  if (( mOverrideCodec || !codec )
+    codec = otp->nodeHelper( )->codec( msg );
+#else
+  kDebug( ) << "AKONADI PORT: Disabled code in  " << Q_FUNC_INFO;
+#endif
+
+  // FIXME why is this here and not in the OTP? - till
 
   // decrypt
   if ( allowDecryption ) {
@@ -1324,18 +1365,25 @@ QString TemplateParser::asPlainTextFromObjectTree( const KMime::Message::Ptr &ms
     }
   }
 
-  if ( result.isEmpty() ) {
-    result = codec->toUnicode( parsedString );
-    if ( result.isEmpty() )
-      return result;
-  }
+  if ( result.isEmpty() )
+    result = codec? codec->toUnicode( parsedString ) : parsedString;
+  if ( result.isEmpty() )
+    return result;
 
   // html -> plaintext conversion, if necessary:
-  if ( isHTML /* TODO port it && mDecodeHTML*/ ) {
-    QWebPage doc;
-    doc.mainFrame()->setHtml( result );
-    result = doc.mainFrame()->toPlainText();
-  }
+#ifdef KDEPIM_NO_WEBKIT
+    if ( isHTML /* TODO port it && mDecodeHTML*/ ) {
+      QTextDocument doc;
+      doc.setHtml( result );
+      result = doc.toPlainText();
+    }
+#else
+    if ( isHTML /* TODO port it && mDecodeHTML*/ ) {
+      QWebPage doc;
+      doc.mainFrame()->setHtml( result );
+      result = doc.mainFrame()->toPlainText();
+    }
+#endif
 
   // strip the signature (footer):
   if ( aStripSignature )
@@ -1390,8 +1438,10 @@ QString TemplateParser::asQuotedString( const KMime::Message::Ptr &msg, const QS
 
   const QString indentStr = MessageCore::StringUtil::formatString( aIndentStr,
                                                                    msg->from()->asUnicodeString() );
+#ifndef Q_OS_WINCE
   if ( GlobalSettings::self()->smartQuote() && mWrap)
     content = MessageCore::StringUtil::smartQuote( content, mColWrap - indentStr.length() );
+#endif
   content.replace( '\n', '\n' + indentStr );
   content.prepend( indentStr );
   content += '\n';
