@@ -33,9 +33,7 @@ class OverViewPage : public QWidget
     ~OverViewPage();
 
   private slots:
-    void showWizardEGroupware();
     void showWizardKolab();
-    void showWizardSlox();
     void showWizardGroupwise();
 
   signals:
